@@ -164,6 +164,7 @@ tds_bcp_init(TDSSOCKET *tds, TDSBCPINFO *bcpinfo)
 		curcol->column_computed = resinfo->columns[i]->column_computed;
 		
 		memcpy(curcol->column_collation, resinfo->columns[i]->column_collation, 5);
+		curcol->use_iconv_out = 0;
 
 		/* From MS documentation:
 		 * Note that for INSERT BULK operations, XMLTYPE is to be sent as NVARCHAR(N) or NVARCHAR(MAX)
@@ -329,7 +330,7 @@ probe_sap_locking(TDSSOCKET *tds, TDSBCPINFO *bcpinfo)
 static TDSRET
 tds7_build_bulk_insert_stmt(TDSSOCKET * tds, TDSPBCB * clause, TDSCOLUMN * bcpcol, int first)
 {
-	char column_type[40];
+	char column_type[128];
 
 	tdsdump_log(TDS_DBG_FUNC, "tds7_build_bulk_insert_stmt(%p, %p, %p, %d)\n", tds, clause, bcpcol, first);
 
@@ -340,6 +341,11 @@ tds7_build_bulk_insert_stmt(TDSSOCKET * tds, TDSPBCB * clause, TDSCOLUMN * bcpco
 		return TDS_FAIL;
 	}
 
+	if (IS_TDS71_PLUS(tds->conn) && bcpcol->char_conv) {
+		strcat(column_type, " COLLATE ");
+		strcat(column_type, tds_canonical_collate_name(bcpcol->char_conv->to.charset.canonic));
+	}
+
 	if (clause->cb < strlen(clause->pb)
 	    + tds_quote_id(tds, NULL, tds_dstr_cstr(&bcpcol->column_name), tds_dstr_len(&bcpcol->column_name))
 	    + strlen(column_type)
